import { LocalizationMap } from 'discord-api-types/v10';
import { ApplicationCommand, ApplicationCommandData, ApplicationCommandOptionData, BaseCommandInteraction, ChatInputApplicationCommandData, CommandInteraction, GuildMember } from 'discord.js';
import { Client, ClientOptions } from 'discord.js';
import { ApplicationCommandTypes } from 'discord.js/typings/enums';
export { Command } from './Interactions/Command';
export { MessageContextMenu } from './Interactions/Message';
export { UserContextMenu } from './Interactions/User';
export { ready } from './Functions/ready';
export { handleCmd } from './Functions/handleCmd';
import { EventEmitter } from 'events'

// make an ApplicationCommandData object from a Command object
export function makeApplicationCommandData(command: Command): ApplicationCommandData {
  return {
      name: command.name,
      nameLocalizations: command.nameLocalizations,
      description: command.description,
      descriptionLocalizations: command.descriptionLocalizations,
      defaultPermission: command.defaultPermission,
      options: command.options,
      type: command.type
  }
}

export function makeUserContextMenu(command: UserContextMenu): ApplicationCommandData {
  return {
      name: command.name,
      nameLocalizations: command.nameLocalizations,
      defaultPermission: command.defaultPermission,
      type: command.type
  }
}

export function makeMessageContextMenu(command: MessageContextMenu): ApplicationCommandData {
  return {
      name: command.name,
      nameLocalizations: command.nameLocalizations,
      defaultPermission: command.defaultPermission,
      type: command.type
  }
}

import fs, { Dirent } from 'fs'
import { Command } from './Interactions/Command';
import { MessageContextMenu } from './Interactions/Message';
import { UserContextMenu } from './Interactions/User';

export const getAllFiles = (dir: string, extension?: string) => {
const files: Dirent[] = fs.readdirSync(dir, {
  withFileTypes: true,
})
let jsFiles: [string, string][] = []

for (const file of files) {
  if (file.isDirectory()) {
    jsFiles = [...jsFiles, ...getAllFiles(`${dir}/${file.name}`, extension)]
  } else if (
    file.name.endsWith(extension || '.js') &&
    !file.name.startsWith('!')
  ) {
    let fileName: string | string[] = file.name.replace(/\\/g, '/').split('/')
    fileName = fileName[fileName.length - 1]
    fileName = fileName.split('.')[0].toLowerCase()

    jsFiles.push([`${dir}/${file.name}`, fileName])
  }
}

return jsFiles
}

declare module 'past-api' {
  export { Command } from './Interactions/Command';
  export { MessageContextMenu } from './Interactions/Message';
  export { UserContextMenu } from './Interactions/User';
  export { ready } from './Functions/ready';
  export { handleCmd } from './Functions/handleCmd';
  export { handleMsg } from './Functions/handleMsg'
  export { handleUser } from './Functions/handleUser'
}